# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/topology/admin/v30/topology_manager_write_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/digitalasset/canton/topology/admin/v30/topology_manager_write_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ....protocol.v30 import topology_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v30_dot_topology__pb2
from . import common_pb2 as com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_common__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nOcom/digitalasset/canton/topology/admin/v30/topology_manager_write_service.proto\x12*com.digitalasset.canton.topology.admin.v30\x1a\x33\x63om/digitalasset/canton/protocol/v30/topology.proto\x1a\x37\x63om/digitalasset/canton/topology/admin/v30/common.proto\x1a\x1egoogle/protobuf/duration.proto\"\xaa\x03\n\x1bGenerateTransactionsRequest\x12n\n\tproposals\x18\x01 \x03(\x0b\x32P.com.digitalasset.canton.topology.admin.v30.GenerateTransactionsRequest.ProposalR\tproposals\x1a\x9a\x02\n\x08Proposal\x12Z\n\toperation\x18\x01 \x01(\x0e\x32<.com.digitalasset.canton.protocol.v30.Enums.TopologyChangeOpR\toperation\x12\x16\n\x06serial\x18\x02 \x01(\rR\x06serial\x12O\n\x07mapping\x18\x03 \x01(\x0b\x32\x35.com.digitalasset.canton.protocol.v30.TopologyMappingR\x07mapping\x12I\n\x05store\x18\x04 \x01(\x0b\x32\x33.com.digitalasset.canton.topology.admin.v30.StoreIdR\x05store\"\xaf\x02\n\x1cGenerateTransactionsResponse\x12\x94\x01\n\x16generated_transactions\x18\x01 \x03(\x0b\x32].com.digitalasset.canton.topology.admin.v30.GenerateTransactionsResponse.GeneratedTransactionR\x15generatedTransactions\x1ax\n\x14GeneratedTransaction\x12\x35\n\x16serialized_transaction\x18\x01 \x01(\x0cR\x15serializedTransaction\x12)\n\x10transaction_hash\x18\x02 \x01(\x0cR\x0ftransactionHash\"\xc2\x05\n\x10\x41uthorizeRequest\x12\x63\n\x08proposal\x18\x01 \x01(\x0b\x32\x45.com.digitalasset.canton.topology.admin.v30.AuthorizeRequest.ProposalH\x00R\x08proposal\x12+\n\x10transaction_hash\x18\x02 \x01(\tH\x00R\x0ftransactionHash\x12\x30\n\x14must_fully_authorize\x18\x03 \x01(\x08R\x12mustFullyAuthorize\x12Z\n\rforce_changes\x18\x04 \x03(\x0e\x32\x35.com.digitalasset.canton.topology.admin.v30.ForceFlagR\x0c\x66orceChanges\x12\x1b\n\tsigned_by\x18\x05 \x03(\tR\x08signedBy\x12I\n\x05store\x18\x06 \x01(\x0b\x32\x33.com.digitalasset.canton.topology.admin.v30.StoreIdR\x05store\x12R\n\x18wait_to_become_effective\x18\x07 \x01(\x0b\x32\x19.google.protobuf.DurationR\x15waitToBecomeEffective\x1a\xc9\x01\n\x08Proposal\x12T\n\x06\x63hange\x18\x01 \x01(\x0e\x32<.com.digitalasset.canton.protocol.v30.Enums.TopologyChangeOpR\x06\x63hange\x12\x16\n\x06serial\x18\x02 \x01(\rR\x06serial\x12O\n\x07mapping\x18\x03 \x01(\x0b\x32\x35.com.digitalasset.canton.protocol.v30.TopologyMappingR\x07mappingB\x06\n\x04type\"v\n\x11\x41uthorizeResponse\x12\x61\n\x0btransaction\x18\x01 \x01(\x0b\x32?.com.digitalasset.canton.protocol.v30.SignedTopologyTransactionR\x0btransaction\"\xf8\x02\n\x16\x41\x64\x64TransactionsRequest\x12\x63\n\x0ctransactions\x18\x01 \x03(\x0b\x32?.com.digitalasset.canton.protocol.v30.SignedTopologyTransactionR\x0ctransactions\x12Z\n\rforce_changes\x18\x02 \x03(\x0e\x32\x35.com.digitalasset.canton.topology.admin.v30.ForceFlagR\x0c\x66orceChanges\x12I\n\x05store\x18\x03 \x01(\x0b\x32\x33.com.digitalasset.canton.topology.admin.v30.StoreIdR\x05store\x12R\n\x18wait_to_become_effective\x18\x07 \x01(\x0b\x32\x19.google.protobuf.DurationR\x15waitToBecomeEffective\"\x19\n\x17\x41\x64\x64TransactionsResponse\"\xeb\x01\n\x1dImportTopologySnapshotRequest\x12+\n\x11topology_snapshot\x18\x01 \x01(\x0cR\x10topologySnapshot\x12I\n\x05store\x18\x02 \x01(\x0b\x32\x33.com.digitalasset.canton.topology.admin.v30.StoreIdR\x05store\x12R\n\x18wait_to_become_effective\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationR\x15waitToBecomeEffective\" \n\x1eImportTopologySnapshotResponse\"\xed\x01\n\x1fImportTopologySnapshotV2Request\x12+\n\x11topology_snapshot\x18\x01 \x01(\x0cR\x10topologySnapshot\x12I\n\x05store\x18\x02 \x01(\x0b\x32\x33.com.digitalasset.canton.topology.admin.v30.StoreIdR\x05store\x12R\n\x18wait_to_become_effective\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationR\x15waitToBecomeEffective\"\"\n ImportTopologySnapshotV2Response\"\xbe\x02\n\x17SignTransactionsRequest\x12\x63\n\x0ctransactions\x18\x01 \x03(\x0b\x32?.com.digitalasset.canton.protocol.v30.SignedTopologyTransactionR\x0ctransactions\x12\x1b\n\tsigned_by\x18\x02 \x03(\tR\x08signedBy\x12I\n\x05store\x18\x03 \x01(\x0b\x32\x33.com.digitalasset.canton.topology.admin.v30.StoreIdR\x05store\x12V\n\x0b\x66orce_flags\x18\x04 \x03(\x0e\x32\x35.com.digitalasset.canton.topology.admin.v30.ForceFlagR\nforceFlags\"\x7f\n\x18SignTransactionsResponse\x12\x63\n\x0ctransactions\x18\x01 \x03(\x0b\x32?.com.digitalasset.canton.protocol.v30.SignedTopologyTransactionR\x0ctransactions\"d\n#CreateTemporaryTopologyStoreRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12)\n\x10protocol_version\x18\x02 \x01(\rR\x0fprotocolVersion\"\x80\x01\n$CreateTemporaryTopologyStoreResponse\x12X\n\x08store_id\x18\x01 \x01(\x0b\x32=.com.digitalasset.canton.topology.admin.v30.StoreId.TemporaryR\x07storeId\"}\n!DropTemporaryTopologyStoreRequest\x12X\n\x08store_id\x18\x01 \x01(\x0b\x32=.com.digitalasset.canton.topology.admin.v30.StoreId.TemporaryR\x07storeId\"$\n\"DropTemporaryTopologyStoreResponse*\x85\x06\n\tForceFlag\x12\x1a\n\x16\x46ORCE_FLAG_UNSPECIFIED\x10\x00\x12\x1b\n\x17\x46ORCE_FLAG_ALIEN_MEMBER\x10\x01\x12\x39\n5FORCE_FLAG_LEDGER_TIME_RECORD_TIME_TOLERANCE_INCREASE\x10\x02\x12$\n FORCE_FLAG_ALLOW_UNKNOWN_PACKAGE\x10\x04\x12*\n&FORCE_FLAG_ALLOW_UNVETTED_DEPENDENCIES\x10\x05\x12\x32\n.FORCE_FLAG_DISABLE_PARTY_WITH_ACTIVE_CONTRACTS\x10\x06\x12-\n)FORCE_FLAG_ALLOW_UNVALIDATED_SIGNING_KEYS\x10\x07\x12>\n:FORCE_FLAG_PREPARATION_TIME_RECORD_TIME_TOLERANCE_INCREASE\x10\t\x12L\nHFORCE_FLAG_ALLOW_INSUFFICIENT_PARTICIPANT_PERMISSION_FOR_SIGNATORY_PARTY\x10\n\x12L\nHFORCE_FLAG_ALLOW_INSUFFICIENT_SIGNATORY_ASSIGNING_PARTICIPANTS_FOR_PARTY\x10\x0b\x12.\n*FORCE_FLAG_ALLOW_VET_INCOMPATIBLE_UPGRADES\x10\x0c\x12(\n$FORCE_FLAG_ALLOW_OUT_OF_BOUNDS_VALUE\x10\r\x12\x37\n3FORCE_FLAG_ALLOW_CONFIRMING_THRESHOLD_CANNOT_BE_MET\x10\x0e\"\x04\x08\x03\x10\x03\"\x04\x08\x08\x10\x08*\x1e\x46ORCE_FLAG_ALLOW_UNVET_PACKAGE*4FORCE_FLAG_ALLOW_UNVET_PACKAGE_WITH_ACTIVE_CONTRACTS2\x81\x0b\n\x1bTopologyManagerWriteService\x12\x88\x01\n\tAuthorize\x12<.com.digitalasset.canton.topology.admin.v30.AuthorizeRequest\x1a=.com.digitalasset.canton.topology.admin.v30.AuthorizeResponse\x12\x9a\x01\n\x0f\x41\x64\x64Transactions\x12\x42.com.digitalasset.canton.topology.admin.v30.AddTransactionsRequest\x1a\x43.com.digitalasset.canton.topology.admin.v30.AddTransactionsResponse\x12\xb1\x01\n\x16ImportTopologySnapshot\x12I.com.digitalasset.canton.topology.admin.v30.ImportTopologySnapshotRequest\x1aJ.com.digitalasset.canton.topology.admin.v30.ImportTopologySnapshotResponse(\x01\x12\xb7\x01\n\x18ImportTopologySnapshotV2\x12K.com.digitalasset.canton.topology.admin.v30.ImportTopologySnapshotV2Request\x1aL.com.digitalasset.canton.topology.admin.v30.ImportTopologySnapshotV2Response(\x01\x12\x9d\x01\n\x10SignTransactions\x12\x43.com.digitalasset.canton.topology.admin.v30.SignTransactionsRequest\x1a\x44.com.digitalasset.canton.topology.admin.v30.SignTransactionsResponse\x12\xa9\x01\n\x14GenerateTransactions\x12G.com.digitalasset.canton.topology.admin.v30.GenerateTransactionsRequest\x1aH.com.digitalasset.canton.topology.admin.v30.GenerateTransactionsResponse\x12\xc1\x01\n\x1c\x43reateTemporaryTopologyStore\x12O.com.digitalasset.canton.topology.admin.v30.CreateTemporaryTopologyStoreRequest\x1aP.com.digitalasset.canton.topology.admin.v30.CreateTemporaryTopologyStoreResponse\x12\xbb\x01\n\x1a\x44ropTemporaryTopologyStore\x12M.com.digitalasset.canton.topology.admin.v30.DropTemporaryTopologyStoreRequest\x1aN.com.digitalasset.canton.topology.admin.v30.DropTemporaryTopologyStoreResponseB[ZYgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/topology/admin/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.topology.admin.v30.topology_manager_write_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZYgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/topology/admin/v30'
  _globals['_FORCEFLAG']._serialized_start=3636
  _globals['_FORCEFLAG']._serialized_end=4409
  _globals['_GENERATETRANSACTIONSREQUEST']._serialized_start=270
  _globals['_GENERATETRANSACTIONSREQUEST']._serialized_end=696
  _globals['_GENERATETRANSACTIONSREQUEST_PROPOSAL']._serialized_start=414
  _globals['_GENERATETRANSACTIONSREQUEST_PROPOSAL']._serialized_end=696
  _globals['_GENERATETRANSACTIONSRESPONSE']._serialized_start=699
  _globals['_GENERATETRANSACTIONSRESPONSE']._serialized_end=1002
  _globals['_GENERATETRANSACTIONSRESPONSE_GENERATEDTRANSACTION']._serialized_start=882
  _globals['_GENERATETRANSACTIONSRESPONSE_GENERATEDTRANSACTION']._serialized_end=1002
  _globals['_AUTHORIZEREQUEST']._serialized_start=1005
  _globals['_AUTHORIZEREQUEST']._serialized_end=1711
  _globals['_AUTHORIZEREQUEST_PROPOSAL']._serialized_start=1502
  _globals['_AUTHORIZEREQUEST_PROPOSAL']._serialized_end=1703
  _globals['_AUTHORIZERESPONSE']._serialized_start=1713
  _globals['_AUTHORIZERESPONSE']._serialized_end=1831
  _globals['_ADDTRANSACTIONSREQUEST']._serialized_start=1834
  _globals['_ADDTRANSACTIONSREQUEST']._serialized_end=2210
  _globals['_ADDTRANSACTIONSRESPONSE']._serialized_start=2212
  _globals['_ADDTRANSACTIONSRESPONSE']._serialized_end=2237
  _globals['_IMPORTTOPOLOGYSNAPSHOTREQUEST']._serialized_start=2240
  _globals['_IMPORTTOPOLOGYSNAPSHOTREQUEST']._serialized_end=2475
  _globals['_IMPORTTOPOLOGYSNAPSHOTRESPONSE']._serialized_start=2477
  _globals['_IMPORTTOPOLOGYSNAPSHOTRESPONSE']._serialized_end=2509
  _globals['_IMPORTTOPOLOGYSNAPSHOTV2REQUEST']._serialized_start=2512
  _globals['_IMPORTTOPOLOGYSNAPSHOTV2REQUEST']._serialized_end=2749
  _globals['_IMPORTTOPOLOGYSNAPSHOTV2RESPONSE']._serialized_start=2751
  _globals['_IMPORTTOPOLOGYSNAPSHOTV2RESPONSE']._serialized_end=2785
  _globals['_SIGNTRANSACTIONSREQUEST']._serialized_start=2788
  _globals['_SIGNTRANSACTIONSREQUEST']._serialized_end=3106
  _globals['_SIGNTRANSACTIONSRESPONSE']._serialized_start=3108
  _globals['_SIGNTRANSACTIONSRESPONSE']._serialized_end=3235
  _globals['_CREATETEMPORARYTOPOLOGYSTOREREQUEST']._serialized_start=3237
  _globals['_CREATETEMPORARYTOPOLOGYSTOREREQUEST']._serialized_end=3337
  _globals['_CREATETEMPORARYTOPOLOGYSTORERESPONSE']._serialized_start=3340
  _globals['_CREATETEMPORARYTOPOLOGYSTORERESPONSE']._serialized_end=3468
  _globals['_DROPTEMPORARYTOPOLOGYSTOREREQUEST']._serialized_start=3470
  _globals['_DROPTEMPORARYTOPOLOGYSTOREREQUEST']._serialized_end=3595
  _globals['_DROPTEMPORARYTOPOLOGYSTORERESPONSE']._serialized_start=3597
  _globals['_DROPTEMPORARYTOPOLOGYSTORERESPONSE']._serialized_end=3633
  _globals['_TOPOLOGYMANAGERWRITESERVICE']._serialized_start=4412
  _globals['_TOPOLOGYMANAGERWRITESERVICE']._serialized_end=5821
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

import builtins as _builtins, typing as _typing

import grpc as _grpc
from google.protobuf.empty_pb2 import Empty
from grpc import aio as _grpc_aio

from .sequencer_initialization_service_pb2 import InitRequest as V0InitRequest, InitResponse, TopologyBootstrapRequest
from ..v1.sequencer_initialization_service_pb2 import InitRequest as V1InitRequest

__all__ = [
    "SequencerInitializationServiceStub",
    "TopologyBootstrapServiceStub",
]


# noinspection PyPep8Naming,DuplicatedCode
class SequencerInitializationServiceStub:
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc.Channel) -> _SequencerInitializationServiceBlockingStub: ...  # type: ignore
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc_aio.Channel) -> _SequencerInitializationServiceAsyncStub: ...  # type: ignore
    def Init(self, __1: V0InitRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[InitResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, InitResponse]]: ...
    def InitV1(self, __1: V1InitRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[InitResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, InitResponse]]: ...

# noinspection PyPep8Naming,DuplicatedCode
class _SequencerInitializationServiceBlockingStub(SequencerInitializationServiceStub):
    def Init(self, __1: V0InitRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> InitResponse: ...
    def InitV1(self, __1: V1InitRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> InitResponse: ...

# noinspection PyPep8Naming,DuplicatedCode
class _SequencerInitializationServiceAsyncStub(SequencerInitializationServiceStub):
    def Init(self, __1: V0InitRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, InitResponse]: ...  # type: ignore
    def InitV1(self, __1: V1InitRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, InitResponse]: ...  # type: ignore

# noinspection PyPep8Naming,DuplicatedCode
class TopologyBootstrapServiceStub:
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc.Channel) -> _TopologyBootstrapServiceBlockingStub: ...  # type: ignore
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc_aio.Channel) -> _TopologyBootstrapServiceAsyncStub: ...  # type: ignore
    def Bootstrap(self, __1: TopologyBootstrapRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[Empty, _grpc_aio.UnaryUnaryCall[_typing.Any, Empty]]: ...

# noinspection PyPep8Naming,DuplicatedCode
class _TopologyBootstrapServiceBlockingStub(TopologyBootstrapServiceStub):
    def Bootstrap(self, __1: TopologyBootstrapRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> Empty: ...

# noinspection PyPep8Naming,DuplicatedCode
class _TopologyBootstrapServiceAsyncStub(TopologyBootstrapServiceStub):
    def Bootstrap(self, __1: TopologyBootstrapRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, Empty]: ...  # type: ignore



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/health/admin/v1/status_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/digitalasset/canton/health/admin/v1/status_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..v0 import status_service_pb2 as com_dot_digitalasset_dot_canton_dot_health_dot_admin_dot_v0_dot_status__service__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<com/digitalasset/canton/health/admin/v1/status_service.proto\x12\'com.digitalasset.canton.health.admin.v1\x1a<com/digitalasset/canton/health/admin/v0/status_service.proto\x1a\x1egoogle/protobuf/duration.proto\".\n\x07\x46\x61ilure\x12#\n\rerror_message\x18\x01 \x01(\tR\x0c\x65rrorMessage\"\xd7\x03\n\x06Status\x12\x10\n\x03uid\x18\x01 \x01(\tR\x03uid\x12\x31\n\x06uptime\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationR\x06uptime\x12P\n\x05ports\x18\x03 \x03(\x0b\x32:.com.digitalasset.canton.health.admin.v1.Status.PortsEntryR\x05ports\x12\x16\n\x06\x61\x63tive\x18\x04 \x01(\x08R\x06\x61\x63tive\x12\x65\n\x0ftopology_queues\x18\x05 \x01(\x0b\x32<.com.digitalasset.canton.health.admin.v0.TopologyQueueStatusR\x0etopologyQueues\x12\x63\n\ncomponents\x18\x06 \x03(\x0b\x32\x43.com.digitalasset.canton.health.admin.v0.NodeStatus.ComponentStatusR\ncomponents\x12\x18\n\x07version\x18\x07 \x01(\tR\x07version\x1a\x38\n\nPortsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x05R\x05value:\x02\x38\x01\x42XZVgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/health/admin/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.health.admin.v1.status_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZVgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/health/admin/v1'
  _globals['_STATUS_PORTSENTRY']._loaded_options = None
  _globals['_STATUS_PORTSENTRY']._serialized_options = b'8\001'
  _globals['_FAILURE']._serialized_start=199
  _globals['_FAILURE']._serialized_end=245
  _globals['_STATUS']._serialized_start=248
  _globals['_STATUS']._serialized_end=719
  _globals['_STATUS_PORTSENTRY']._serialized_start=663
  _globals['_STATUS_PORTSENTRY']._serialized_end=719
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from __future__ import annotations

from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.identity_provider_config import IdentityProviderConfig


T = TypeVar("T", bound="ListIdentityProviderConfigsResponse")


@_attrs_define
class ListIdentityProviderConfigsResponse:
    """
    Attributes:
        identity_provider_configs (list[IdentityProviderConfig] | Unset):
    """

    identity_provider_configs: list[IdentityProviderConfig] | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        identity_provider_configs: list[dict[str, Any]] | Unset = UNSET
        if not isinstance(self.identity_provider_configs, Unset):
            identity_provider_configs = []
            for identity_provider_configs_item_data in self.identity_provider_configs:
                identity_provider_configs_item = (
                    identity_provider_configs_item_data.to_dict()
                )
                identity_provider_configs.append(identity_provider_configs_item)

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if identity_provider_configs is not UNSET:
            field_dict["identityProviderConfigs"] = identity_provider_configs

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.identity_provider_config import IdentityProviderConfig

        d = dict(src_dict)
        _identity_provider_configs = d.pop("identityProviderConfigs", UNSET)
        identity_provider_configs: list[IdentityProviderConfig] | Unset = UNSET
        if _identity_provider_configs is not UNSET:
            identity_provider_configs = []
            for identity_provider_configs_item_data in _identity_provider_configs:
                identity_provider_configs_item = IdentityProviderConfig.from_dict(
                    identity_provider_configs_item_data
                )

                identity_provider_configs.append(identity_provider_configs_item)

        list_identity_provider_configs_response = cls(
            identity_provider_configs=identity_provider_configs,
        )

        list_identity_provider_configs_response.additional_properties = d
        return list_identity_provider_configs_response

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from __future__ import annotations

from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.map_string import MapString


T = TypeVar("T", bound="JsCantonError")


@_attrs_define
class JsCantonError:
    """
    Attributes:
        code (str):
        cause (str):
        context (MapString):
        error_category (int):
        correlation_id (str | Unset):
        trace_id (str | Unset):
        resources (list[list[str]] | Unset):
        grpc_code_value (int | Unset):
        retry_info (str | Unset):
        definite_answer (bool | Unset):
    """

    code: str
    cause: str
    context: MapString
    error_category: int
    correlation_id: str | Unset = UNSET
    trace_id: str | Unset = UNSET
    resources: list[list[str]] | Unset = UNSET
    grpc_code_value: int | Unset = UNSET
    retry_info: str | Unset = UNSET
    definite_answer: bool | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        code = self.code

        cause = self.cause

        context = self.context.to_dict()

        error_category = self.error_category

        correlation_id = self.correlation_id

        trace_id = self.trace_id

        resources: list[list[str]] | Unset = UNSET
        if not isinstance(self.resources, Unset):
            resources = []
            for resources_item_data in self.resources:
                resources_item = resources_item_data

                resources.append(resources_item)

        grpc_code_value = self.grpc_code_value

        retry_info = self.retry_info

        definite_answer = self.definite_answer

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "code": code,
                "cause": cause,
                "context": context,
                "errorCategory": error_category,
            }
        )
        if correlation_id is not UNSET:
            field_dict["correlationId"] = correlation_id
        if trace_id is not UNSET:
            field_dict["traceId"] = trace_id
        if resources is not UNSET:
            field_dict["resources"] = resources
        if grpc_code_value is not UNSET:
            field_dict["grpcCodeValue"] = grpc_code_value
        if retry_info is not UNSET:
            field_dict["retryInfo"] = retry_info
        if definite_answer is not UNSET:
            field_dict["definiteAnswer"] = definite_answer

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.map_string import MapString

        d = dict(src_dict)
        code = d.pop("code")

        cause = d.pop("cause")

        context = MapString.from_dict(d.pop("context"))

        error_category = d.pop("errorCategory")

        correlation_id = d.pop("correlationId", UNSET)

        trace_id = d.pop("traceId", UNSET)

        _resources = d.pop("resources", UNSET)
        resources: list[list[str]] | Unset = UNSET
        if _resources is not UNSET:
            resources = []
            for resources_item_data in _resources:
                resources_item = cast(list[str], resources_item_data)

                resources.append(resources_item)

        grpc_code_value = d.pop("grpcCodeValue", UNSET)

        retry_info = d.pop("retryInfo", UNSET)

        definite_answer = d.pop("definiteAnswer", UNSET)

        js_canton_error = cls(
            code=code,
            cause=cause,
            context=context,
            error_category=error_category,
            correlation_id=correlation_id,
            trace_id=trace_id,
            resources=resources,
            grpc_code_value=grpc_code_value,
            retry_info=retry_info,
            definite_answer=definite_answer,
        )

        js_canton_error.additional_properties = d
        return js_canton_error

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class ContractImportMode(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    CONTRACT_IMPORT_MODE_UNSPECIFIED: _ClassVar[ContractImportMode]
    CONTRACT_IMPORT_MODE_ACCEPT: _ClassVar[ContractImportMode]
    CONTRACT_IMPORT_MODE_VALIDATION: _ClassVar[ContractImportMode]
    CONTRACT_IMPORT_MODE_RECOMPUTATION: _ClassVar[ContractImportMode]
CONTRACT_IMPORT_MODE_UNSPECIFIED: ContractImportMode
CONTRACT_IMPORT_MODE_ACCEPT: ContractImportMode
CONTRACT_IMPORT_MODE_VALIDATION: ContractImportMode
CONTRACT_IMPORT_MODE_RECOMPUTATION: ContractImportMode

class RepresentativePackageIdOverride(_message.Message):
    __slots__ = ("contract_override", "package_id_override", "package_name_override")
    class ContractOverrideEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    class PackageIdOverrideEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    class PackageNameOverrideEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    CONTRACT_OVERRIDE_FIELD_NUMBER: _ClassVar[int]
    PACKAGE_ID_OVERRIDE_FIELD_NUMBER: _ClassVar[int]
    PACKAGE_NAME_OVERRIDE_FIELD_NUMBER: _ClassVar[int]
    contract_override: _containers.ScalarMap[str, str]
    package_id_override: _containers.ScalarMap[str, str]
    package_name_override: _containers.ScalarMap[str, str]
    def __init__(self, contract_override: _Optional[_Mapping[str, str]] = ..., package_id_override: _Optional[_Mapping[str, str]] = ..., package_name_override: _Optional[_Mapping[str, str]] = ...) -> None: ...



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/daml/ledger/api/v2/interactive/interactive_submission_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/daml/ledger/api/v2/interactive/interactive_submission_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .. import commands_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_commands__pb2
from .. import crypto_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_crypto__pb2
from . import interactive_submission_common_data_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_interactive_dot_interactive__submission__common__data__pb2
from .transaction.v1 import interactive_submission_data_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_interactive_dot_transaction_dot_v1_dot_interactive__submission__data__pb2
from .. import package_reference_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_package__reference__pb2
from .. import transaction_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_transaction__pb2
from .. import transaction_filter_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_transaction__filter__pb2
from .. import value_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_value__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGcom/daml/ledger/api/v2/interactive/interactive_submission_service.proto\x12\"com.daml.ledger.api.v2.interactive\x1a%com/daml/ledger/api/v2/commands.proto\x1a#com/daml/ledger/api/v2/crypto.proto\x1aKcom/daml/ledger/api/v2/interactive/interactive_submission_common_data.proto\x1aScom/daml/ledger/api/v2/interactive/transaction/v1/interactive_submission_data.proto\x1a.com/daml/ledger/api/v2/package_reference.proto\x1a(com/daml/ledger/api/v2/transaction.proto\x1a/com/daml/ledger/api/v2/transaction_filter.proto\x1a\"com/daml/ledger/api/v2/value.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x90\x01\n\x13\x43ostEstimationHints\x12\x1a\n\x08\x64isabled\x18\x01 \x01(\x08R\x08\x64isabled\x12]\n\x13\x65xpected_signatures\x18\x02 \x03(\x0e\x32,.com.daml.ledger.api.v2.SigningAlgorithmSpecR\x12\x65xpectedSignatures\"\xe4\x02\n\x0e\x43ostEstimation\x12M\n\x14\x65stimation_timestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x13\x65stimationTimestamp\x12^\n,confirmation_request_traffic_cost_estimation\x18\x02 \x01(\x04R(confirmationRequestTrafficCostEstimation\x12`\n-confirmation_response_traffic_cost_estimation\x18\x03 \x01(\x04R)confirmationResponseTrafficCostEstimation\x12\x41\n\x1dtotal_traffic_cost_estimation\x18\x04 \x01(\x04R\x1atotalTrafficCostEstimation\"\xdb\x06\n\x18PrepareSubmissionRequest\x12\x17\n\x07user_id\x18\x01 \x01(\tR\x06userId\x12\x1d\n\ncommand_id\x18\x02 \x01(\tR\tcommandId\x12;\n\x08\x63ommands\x18\x03 \x03(\x0b\x32\x1f.com.daml.ledger.api.v2.CommandR\x08\x63ommands\x12Y\n\x0fmin_ledger_time\x18\x04 \x01(\x0b\x32\x31.com.daml.ledger.api.v2.interactive.MinLedgerTimeR\rminLedgerTime\x12G\n\x0fmax_record_time\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00R\rmaxRecordTime\x88\x01\x01\x12\x15\n\x06\x61\x63t_as\x18\x05 \x03(\tR\x05\x61\x63tAs\x12\x17\n\x07read_as\x18\x06 \x03(\tR\x06readAs\x12Z\n\x13\x64isclosed_contracts\x18\x07 \x03(\x0b\x32).com.daml.ledger.api.v2.DisclosedContractR\x12\x64isclosedContracts\x12\'\n\x0fsynchronizer_id\x18\x08 \x01(\tR\x0esynchronizerId\x12\x45\n\x1fpackage_id_selection_preference\x18\t \x03(\tR\x1cpackageIdSelectionPreference\x12\'\n\x0fverbose_hashing\x18\n \x01(\x08R\x0everboseHashing\x12\x61\n\x16prefetch_contract_keys\x18\x0f \x03(\x0b\x32+.com.daml.ledger.api.v2.PrefetchContractKeyR\x14prefetchContractKeys\x12p\n\x15\x65stimate_traffic_cost\x18\x10 \x01(\x0b\x32\x37.com.daml.ledger.api.v2.interactive.CostEstimationHintsH\x01R\x13\x65stimateTrafficCost\x88\x01\x01\x42\x12\n\x10_max_record_timeB\x18\n\x16_estimate_traffic_cost\"\xeb\x03\n\x19PrepareSubmissionResponse\x12j\n\x14prepared_transaction\x18\x01 \x01(\x0b\x32\x37.com.daml.ledger.api.v2.interactive.PreparedTransactionR\x13preparedTransaction\x12:\n\x19prepared_transaction_hash\x18\x02 \x01(\x0cR\x17preparedTransactionHash\x12n\n\x16hashing_scheme_version\x18\x03 \x01(\x0e\x32\x38.com.daml.ledger.api.v2.interactive.HashingSchemeVersionR\x14hashingSchemeVersion\x12,\n\x0fhashing_details\x18\x04 \x01(\tH\x00R\x0ehashingDetails\x88\x01\x01\x12`\n\x0f\x63ost_estimation\x18\x05 \x01(\x0b\x32\x32.com.daml.ledger.api.v2.interactive.CostEstimationH\x01R\x0e\x63ostEstimation\x88\x01\x01\x42\x12\n\x10_hashing_detailsB\x12\n\x10_cost_estimation\"p\n\x15SinglePartySignatures\x12\x14\n\x05party\x18\x01 \x01(\tR\x05party\x12\x41\n\nsignatures\x18\x02 \x03(\x0b\x32!.com.daml.ledger.api.v2.SignatureR\nsignatures\"l\n\x0fPartySignatures\x12Y\n\nsignatures\x18\x01 \x03(\x0b\x32\x39.com.daml.ledger.api.v2.interactive.SinglePartySignaturesR\nsignatures\"\x90\x05\n\x18\x45xecuteSubmissionRequest\x12j\n\x14prepared_transaction\x18\x01 \x01(\x0b\x32\x37.com.daml.ledger.api.v2.interactive.PreparedTransactionR\x13preparedTransaction\x12^\n\x10party_signatures\x18\x02 \x01(\x0b\x32\x33.com.daml.ledger.api.v2.interactive.PartySignaturesR\x0fpartySignatures\x12R\n\x16\x64\x65\x64uplication_duration\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationH\x00R\x15\x64\x65\x64uplicationDuration\x12\x33\n\x14\x64\x65\x64uplication_offset\x18\x04 \x01(\x03H\x00R\x13\x64\x65\x64uplicationOffset\x12#\n\rsubmission_id\x18\x05 \x01(\tR\x0csubmissionId\x12\x17\n\x07user_id\x18\x06 \x01(\tR\x06userId\x12n\n\x16hashing_scheme_version\x18\x07 \x01(\x0e\x32\x38.com.daml.ledger.api.v2.interactive.HashingSchemeVersionR\x14hashingSchemeVersion\x12Y\n\x0fmin_ledger_time\x18\x08 \x01(\x0b\x32\x31.com.daml.ledger.api.v2.interactive.MinLedgerTimeR\rminLedgerTimeB\x16\n\x14\x64\x65\x64uplication_period\"\x1b\n\x19\x45xecuteSubmissionResponse\"\x97\x05\n\x1f\x45xecuteSubmissionAndWaitRequest\x12j\n\x14prepared_transaction\x18\x01 \x01(\x0b\x32\x37.com.daml.ledger.api.v2.interactive.PreparedTransactionR\x13preparedTransaction\x12^\n\x10party_signatures\x18\x02 \x01(\x0b\x32\x33.com.daml.ledger.api.v2.interactive.PartySignaturesR\x0fpartySignatures\x12R\n\x16\x64\x65\x64uplication_duration\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationH\x00R\x15\x64\x65\x64uplicationDuration\x12\x33\n\x14\x64\x65\x64uplication_offset\x18\x04 \x01(\x03H\x00R\x13\x64\x65\x64uplicationOffset\x12#\n\rsubmission_id\x18\x05 \x01(\tR\x0csubmissionId\x12\x17\n\x07user_id\x18\x06 \x01(\tR\x06userId\x12n\n\x16hashing_scheme_version\x18\x07 \x01(\x0e\x32\x38.com.daml.ledger.api.v2.interactive.HashingSchemeVersionR\x14hashingSchemeVersion\x12Y\n\x0fmin_ledger_time\x18\x08 \x01(\x0b\x32\x31.com.daml.ledger.api.v2.interactive.MinLedgerTimeR\rminLedgerTimeB\x16\n\x14\x64\x65\x64uplication_period\"l\n ExecuteSubmissionAndWaitResponse\x12\x1b\n\tupdate_id\x18\x01 \x01(\tR\x08updateId\x12+\n\x11\x63ompletion_offset\x18\x02 \x01(\x03R\x10\x63ompletionOffset\"\xff\x05\n-ExecuteSubmissionAndWaitForTransactionRequest\x12j\n\x14prepared_transaction\x18\x01 \x01(\x0b\x32\x37.com.daml.ledger.api.v2.interactive.PreparedTransactionR\x13preparedTransaction\x12^\n\x10party_signatures\x18\x02 \x01(\x0b\x32\x33.com.daml.ledger.api.v2.interactive.PartySignaturesR\x0fpartySignatures\x12R\n\x16\x64\x65\x64uplication_duration\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationH\x00R\x15\x64\x65\x64uplicationDuration\x12\x33\n\x14\x64\x65\x64uplication_offset\x18\x04 \x01(\x03H\x00R\x13\x64\x65\x64uplicationOffset\x12#\n\rsubmission_id\x18\x05 \x01(\tR\x0csubmissionId\x12\x17\n\x07user_id\x18\x06 \x01(\tR\x06userId\x12n\n\x16hashing_scheme_version\x18\x07 \x01(\x0e\x32\x38.com.daml.ledger.api.v2.interactive.HashingSchemeVersionR\x14hashingSchemeVersion\x12Y\n\x0fmin_ledger_time\x18\x08 \x01(\x0b\x32\x31.com.daml.ledger.api.v2.interactive.MinLedgerTimeR\rminLedgerTime\x12X\n\x12transaction_format\x18\t \x01(\x0b\x32).com.daml.ledger.api.v2.TransactionFormatR\x11transactionFormatB\x16\n\x14\x64\x65\x64uplication_period\"w\n.ExecuteSubmissionAndWaitForTransactionResponse\x12\x45\n\x0btransaction\x18\x01 \x01(\x0b\x32#.com.daml.ledger.api.v2.TransactionR\x0btransaction\"\xb0\x01\n\rMinLedgerTime\x12K\n\x13min_ledger_time_abs\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00R\x10minLedgerTimeAbs\x12J\n\x13min_ledger_time_rel\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationH\x00R\x10minLedgerTimeRelB\x06\n\x04time\"\xb6\x01\n\x13PreparedTransaction\x12U\n\x0btransaction\x18\x01 \x01(\x0b\x32\x33.com.daml.ledger.api.v2.interactive.DamlTransactionR\x0btransaction\x12H\n\x08metadata\x18\x02 \x01(\x0b\x32,.com.daml.ledger.api.v2.interactive.MetadataR\x08metadata\"\x86\t\n\x08Metadata\x12\x61\n\x0esubmitter_info\x18\x02 \x01(\x0b\x32:.com.daml.ledger.api.v2.interactive.Metadata.SubmitterInfoR\rsubmitterInfo\x12\'\n\x0fsynchronizer_id\x18\x03 \x01(\tR\x0esynchronizerId\x12%\n\x0emediator_group\x18\x04 \x01(\rR\rmediatorGroup\x12)\n\x10transaction_uuid\x18\x05 \x01(\tR\x0ftransactionUuid\x12)\n\x10preparation_time\x18\x06 \x01(\x04R\x0fpreparationTime\x12\x63\n\x0finput_contracts\x18\x07 \x03(\x0b\x32:.com.daml.ledger.api.v2.interactive.Metadata.InputContractR\x0einputContracts\x12>\n\x19min_ledger_effective_time\x18\t \x01(\x04H\x00R\x16minLedgerEffectiveTime\x88\x01\x01\x12>\n\x19max_ledger_effective_time\x18\n \x01(\x04H\x01R\x16maxLedgerEffectiveTime\x88\x01\x01\x12p\n\x12global_key_mapping\x18\x08 \x03(\x0b\x32\x42.com.daml.ledger.api.v2.interactive.Metadata.GlobalKeyMappingEntryR\x10globalKeyMapping\x12+\n\x0fmax_record_time\x18\x0b \x01(\x04H\x02R\rmaxRecordTime\x88\x01\x01\x1a\x45\n\rSubmitterInfo\x12\x15\n\x06\x61\x63t_as\x18\x01 \x03(\tR\x05\x61\x63tAs\x12\x1d\n\ncommand_id\x18\x02 \x01(\tR\tcommandId\x1a\x9c\x01\n\x15GlobalKeyMappingEntry\x12?\n\x03key\x18\x01 \x01(\x0b\x32-.com.daml.ledger.api.v2.interactive.GlobalKeyR\x03key\x12\x38\n\x05value\x18\x02 \x01(\x0b\x32\x1d.com.daml.ledger.api.v2.ValueH\x00R\x05value\x88\x01\x01\x42\x08\n\x06_value\x1a\xb0\x01\n\rInputContract\x12K\n\x02v1\x18\x01 \x01(\x0b\x32\x39.com.daml.ledger.api.v2.interactive.transaction.v1.CreateH\x00R\x02v1\x12\x1e\n\ncreated_at\x18\xe8\x07 \x01(\x04R\tcreatedAt\x12\x1e\n\nevent_blob\x18\xea\x07 \x01(\x0cR\teventBlobB\n\n\x08\x63ontractJ\x06\x08\xe9\x07\x10\xea\x07\x42\x1c\n\x1a_min_ledger_effective_timeB\x1c\n\x1a_max_ledger_effective_timeB\x12\n\x10_max_record_timeJ\x04\x08\x01\x10\x02\"\xa6\x03\n\x0f\x44\x61mlTransaction\x12\x18\n\x07version\x18\x01 \x01(\tR\x07version\x12\x14\n\x05roots\x18\x02 \x03(\tR\x05roots\x12N\n\x05nodes\x18\x03 \x03(\x0b\x32\x38.com.daml.ledger.api.v2.interactive.DamlTransaction.NodeR\x05nodes\x12[\n\nnode_seeds\x18\x04 \x03(\x0b\x32<.com.daml.ledger.api.v2.interactive.DamlTransaction.NodeSeedR\tnodeSeeds\x1a\x37\n\x08NodeSeed\x12\x17\n\x07node_id\x18\x01 \x01(\x05R\x06nodeId\x12\x12\n\x04seed\x18\x02 \x01(\x0cR\x04seed\x1a}\n\x04Node\x12\x17\n\x07node_id\x18\x01 \x01(\tR\x06nodeId\x12J\n\x02v1\x18\xe8\x07 \x01(\x0b\x32\x37.com.daml.ledger.api.v2.interactive.transaction.v1.NodeH\x00R\x02v1B\x10\n\x0eversioned_node\"\xcf\x01\n!GetPreferredPackageVersionRequest\x12\x18\n\x07parties\x18\x01 \x03(\tR\x07parties\x12!\n\x0cpackage_name\x18\x02 \x01(\tR\x0bpackageName\x12\'\n\x0fsynchronizer_id\x18\x03 \x01(\tR\x0esynchronizerId\x12\x44\n\x10vetting_valid_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0evettingValidAt\"\x8a\x01\n\"GetPreferredPackageVersionResponse\x12\x64\n\x12package_preference\x18\x01 \x01(\x0b\x32\x35.com.daml.ledger.api.v2.interactive.PackagePreferenceR\x11packagePreference\"\x93\x01\n\x11PackagePreference\x12U\n\x11package_reference\x18\x01 \x01(\x0b\x32(.com.daml.ledger.api.v2.PackageReferenceR\x10packageReference\x12\'\n\x0fsynchronizer_id\x18\x02 \x01(\tR\x0esynchronizerId\"X\n\x19PackageVettingRequirement\x12\x18\n\x07parties\x18\x01 \x03(\tR\x07parties\x12!\n\x0cpackage_name\x18\x02 \x01(\tR\x0bpackageName\"\x8d\x02\n\x1bGetPreferredPackagesRequest\x12\x7f\n\x1cpackage_vetting_requirements\x18\x01 \x03(\x0b\x32=.com.daml.ledger.api.v2.interactive.PackageVettingRequirementR\x1apackageVettingRequirements\x12\'\n\x0fsynchronizer_id\x18\x02 \x01(\tR\x0esynchronizerId\x12\x44\n\x10vetting_valid_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0evettingValidAt\"\xa0\x01\n\x1cGetPreferredPackagesResponse\x12W\n\x12package_references\x18\x01 \x03(\x0b\x32(.com.daml.ledger.api.v2.PackageReferenceR\x11packageReferences\x12\'\n\x0fsynchronizer_id\x18\x02 \x01(\tR\x0esynchronizerId*c\n\x14HashingSchemeVersion\x12&\n\"HASHING_SCHEME_VERSION_UNSPECIFIED\x10\x00\x12\x1d\n\x19HASHING_SCHEME_VERSION_V2\x10\x02\"\x04\x08\x01\x10\x01\x32\x88\x08\n\x1cInteractiveSubmissionService\x12\x90\x01\n\x11PrepareSubmission\x12<.com.daml.ledger.api.v2.interactive.PrepareSubmissionRequest\x1a=.com.daml.ledger.api.v2.interactive.PrepareSubmissionResponse\x12\x90\x01\n\x11\x45xecuteSubmission\x12<.com.daml.ledger.api.v2.interactive.ExecuteSubmissionRequest\x1a=.com.daml.ledger.api.v2.interactive.ExecuteSubmissionResponse\x12\xa5\x01\n\x18\x45xecuteSubmissionAndWait\x12\x43.com.daml.ledger.api.v2.interactive.ExecuteSubmissionAndWaitRequest\x1a\x44.com.daml.ledger.api.v2.interactive.ExecuteSubmissionAndWaitResponse\x12\xcf\x01\n&ExecuteSubmissionAndWaitForTransaction\x12Q.com.daml.ledger.api.v2.interactive.ExecuteSubmissionAndWaitForTransactionRequest\x1aR.com.daml.ledger.api.v2.interactive.ExecuteSubmissionAndWaitForTransactionResponse\x12\xab\x01\n\x1aGetPreferredPackageVersion\x12\x45.com.daml.ledger.api.v2.interactive.GetPreferredPackageVersionRequest\x1a\x46.com.daml.ledger.api.v2.interactive.GetPreferredPackageVersionResponse\x12\x99\x01\n\x14GetPreferredPackages\x12?.com.daml.ledger.api.v2.interactive.GetPreferredPackagesRequest\x1a@.com.daml.ledger.api.v2.interactive.GetPreferredPackagesResponseB\xc4\x01\n\"com.daml.ledger.api.v2.interactiveB&InteractiveSubmissionServiceOuterClassZQgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v2/interactive\xaa\x02\"Com.Daml.Ledger.Api.V2.Interactiveb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.daml.ledger.api.v2.interactive.interactive_submission_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"com.daml.ledger.api.v2.interactiveB&InteractiveSubmissionServiceOuterClassZQgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v2/interactive\252\002\"Com.Daml.Ledger.Api.V2.Interactive'
  _globals['_HASHINGSCHEMEVERSION']._serialized_start=8006
  _globals['_HASHINGSCHEMEVERSION']._serialized_end=8105
  _globals['_COSTESTIMATIONHINTS']._serialized_start=590
  _globals['_COSTESTIMATIONHINTS']._serialized_end=734
  _globals['_COSTESTIMATION']._serialized_start=737
  _globals['_COSTESTIMATION']._serialized_end=1093
  _globals['_PREPARESUBMISSIONREQUEST']._serialized_start=1096
  _globals['_PREPARESUBMISSIONREQUEST']._serialized_end=1955
  _globals['_PREPARESUBMISSIONRESPONSE']._serialized_start=1958
  _globals['_PREPARESUBMISSIONRESPONSE']._serialized_end=2449
  _globals['_SINGLEPARTYSIGNATURES']._serialized_start=2451
  _globals['_SINGLEPARTYSIGNATURES']._serialized_end=2563
  _globals['_PARTYSIGNATURES']._serialized_start=2565
  _globals['_PARTYSIGNATURES']._serialized_end=2673
  _globals['_EXECUTESUBMISSIONREQUEST']._serialized_start=2676
  _globals['_EXECUTESUBMISSIONREQUEST']._serialized_end=3332
  _globals['_EXECUTESUBMISSIONRESPONSE']._serialized_start=3334
  _globals['_EXECUTESUBMISSIONRESPONSE']._serialized_end=3361
  _globals['_EXECUTESUBMISSIONANDWAITREQUEST']._serialized_start=3364
  _globals['_EXECUTESUBMISSIONANDWAITREQUEST']._serialized_end=4027
  _globals['_EXECUTESUBMISSIONANDWAITRESPONSE']._serialized_start=4029
  _globals['_EXECUTESUBMISSIONANDWAITRESPONSE']._serialized_end=4137
  _globals['_EXECUTESUBMISSIONANDWAITFORTRANSACTIONREQUEST']._serialized_start=4140
  _globals['_EXECUTESUBMISSIONANDWAITFORTRANSACTIONREQUEST']._serialized_end=4907
  _globals['_EXECUTESUBMISSIONANDWAITFORTRANSACTIONRESPONSE']._serialized_start=4909
  _globals['_EXECUTESUBMISSIONANDWAITFORTRANSACTIONRESPONSE']._serialized_end=5028
  _globals['_MINLEDGERTIME']._serialized_start=5031
  _globals['_MINLEDGERTIME']._serialized_end=5207
  _globals['_PREPAREDTRANSACTION']._serialized_start=5210
  _globals['_PREPAREDTRANSACTION']._serialized_end=5392
  _globals['_METADATA']._serialized_start=5395
  _globals['_METADATA']._serialized_end=6553
  _globals['_METADATA_SUBMITTERINFO']._serialized_start=6060
  _globals['_METADATA_SUBMITTERINFO']._serialized_end=6129
  _globals['_METADATA_GLOBALKEYMAPPINGENTRY']._serialized_start=6132
  _globals['_METADATA_GLOBALKEYMAPPINGENTRY']._serialized_end=6288
  _globals['_METADATA_INPUTCONTRACT']._serialized_start=6291
  _globals['_METADATA_INPUTCONTRACT']._serialized_end=6467
  _globals['_DAMLTRANSACTION']._serialized_start=6556
  _globals['_DAMLTRANSACTION']._serialized_end=6978
  _globals['_DAMLTRANSACTION_NODESEED']._serialized_start=6796
  _globals['_DAMLTRANSACTION_NODESEED']._serialized_end=6851
  _globals['_DAMLTRANSACTION_NODE']._serialized_start=6853
  _globals['_DAMLTRANSACTION_NODE']._serialized_end=6978
  _globals['_GETPREFERREDPACKAGEVERSIONREQUEST']._serialized_start=6981
  _globals['_GETPREFERREDPACKAGEVERSIONREQUEST']._serialized_end=7188
  _globals['_GETPREFERREDPACKAGEVERSIONRESPONSE']._serialized_start=7191
  _globals['_GETPREFERREDPACKAGEVERSIONRESPONSE']._serialized_end=7329
  _globals['_PACKAGEPREFERENCE']._serialized_start=7332
  _globals['_PACKAGEPREFERENCE']._serialized_end=7479
  _globals['_PACKAGEVETTINGREQUIREMENT']._serialized_start=7481
  _globals['_PACKAGEVETTINGREQUIREMENT']._serialized_end=7569
  _globals['_GETPREFERREDPACKAGESREQUEST']._serialized_start=7572
  _globals['_GETPREFERREDPACKAGESREQUEST']._serialized_end=7841
  _globals['_GETPREFERREDPACKAGESRESPONSE']._serialized_start=7844
  _globals['_GETPREFERREDPACKAGESRESPONSE']._serialized_end=8004
  _globals['_INTERACTIVESUBMISSIONSERVICE']._serialized_start=8108
  _globals['_INTERACTIVESUBMISSIONSERVICE']._serialized_end=9140
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from ...health.v30 import status_service_pb2 as _status_service_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SequencerStatusRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class SequencerStatusResponse(_message.Message):
    __slots__ = ("status", "not_initialized")
    class ConnectedParticipant(_message.Message):
        __slots__ = ("uid",)
        UID_FIELD_NUMBER: _ClassVar[int]
        uid: str
        def __init__(self, uid: _Optional[str] = ...) -> None: ...
    class ConnectedMediator(_message.Message):
        __slots__ = ("uid",)
        UID_FIELD_NUMBER: _ClassVar[int]
        uid: str
        def __init__(self, uid: _Optional[str] = ...) -> None: ...
    class SequencerStatusResponseStatus(_message.Message):
        __slots__ = ("common_status", "connected_participants", "connected_mediators", "sequencer", "physical_synchronizer_id", "admin", "protocol_version")
        COMMON_STATUS_FIELD_NUMBER: _ClassVar[int]
        CONNECTED_PARTICIPANTS_FIELD_NUMBER: _ClassVar[int]
        CONNECTED_MEDIATORS_FIELD_NUMBER: _ClassVar[int]
        SEQUENCER_FIELD_NUMBER: _ClassVar[int]
        PHYSICAL_SYNCHRONIZER_ID_FIELD_NUMBER: _ClassVar[int]
        ADMIN_FIELD_NUMBER: _ClassVar[int]
        PROTOCOL_VERSION_FIELD_NUMBER: _ClassVar[int]
        common_status: _status_service_pb2.Status
        connected_participants: _containers.RepeatedCompositeFieldContainer[SequencerStatusResponse.ConnectedParticipant]
        connected_mediators: _containers.RepeatedCompositeFieldContainer[SequencerStatusResponse.ConnectedMediator]
        sequencer: SequencerHealthStatus
        physical_synchronizer_id: str
        admin: SequencerAdminStatus
        protocol_version: int
        def __init__(self, common_status: _Optional[_Union[_status_service_pb2.Status, _Mapping]] = ..., connected_participants: _Optional[_Iterable[_Union[SequencerStatusResponse.ConnectedParticipant, _Mapping]]] = ..., connected_mediators: _Optional[_Iterable[_Union[SequencerStatusResponse.ConnectedMediator, _Mapping]]] = ..., sequencer: _Optional[_Union[SequencerHealthStatus, _Mapping]] = ..., physical_synchronizer_id: _Optional[str] = ..., admin: _Optional[_Union[SequencerAdminStatus, _Mapping]] = ..., protocol_version: _Optional[int] = ...) -> None: ...
    STATUS_FIELD_NUMBER: _ClassVar[int]
    NOT_INITIALIZED_FIELD_NUMBER: _ClassVar[int]
    status: SequencerStatusResponse.SequencerStatusResponseStatus
    not_initialized: _status_service_pb2.NotInitialized
    def __init__(self, status: _Optional[_Union[SequencerStatusResponse.SequencerStatusResponseStatus, _Mapping]] = ..., not_initialized: _Optional[_Union[_status_service_pb2.NotInitialized, _Mapping]] = ...) -> None: ...

class SequencerHealthStatus(_message.Message):
    __slots__ = ("active", "details")
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    DETAILS_FIELD_NUMBER: _ClassVar[int]
    active: bool
    details: str
    def __init__(self, active: bool = ..., details: _Optional[str] = ...) -> None: ...

class SequencerAdminStatus(_message.Message):
    __slots__ = ("accepts_admin_changes",)
    ACCEPTS_ADMIN_CHANGES_FIELD_NUMBER: _ClassVar[int]
    accepts_admin_changes: bool
    def __init__(self, accepts_admin_changes: bool = ...) -> None: ...



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

T = TypeVar("T", bound="UpdateUserIdentityProviderIdRequest")


@_attrs_define
class UpdateUserIdentityProviderIdRequest:
    """Required authorization: ``HasRight(ParticipantAdmin)``

    Attributes:
        user_id (str): User to update
        source_identity_provider_id (str): Current identity provider ID of the user
        target_identity_provider_id (str): Target identity provider ID of the user
    """

    user_id: str
    source_identity_provider_id: str
    target_identity_provider_id: str
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        user_id = self.user_id

        source_identity_provider_id = self.source_identity_provider_id

        target_identity_provider_id = self.target_identity_provider_id

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "userId": user_id,
                "sourceIdentityProviderId": source_identity_provider_id,
                "targetIdentityProviderId": target_identity_provider_id,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        user_id = d.pop("userId")

        source_identity_provider_id = d.pop("sourceIdentityProviderId")

        target_identity_provider_id = d.pop("targetIdentityProviderId")

        update_user_identity_provider_id_request = cls(
            user_id=user_id,
            source_identity_provider_id=source_identity_provider_id,
            target_identity_provider_id=target_identity_provider_id,
        )

        update_user_identity_provider_id_request.additional_properties = d
        return update_user_identity_provider_id_request

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/protocol/v2/participant_transfer.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/digitalasset/canton/protocol/v2/participant_transfer.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ...crypto.v0 import crypto_pb2 as com_dot_digitalasset_dot_canton_dot_crypto_dot_v0_dot_crypto__pb2
from ..v0 import sequencing_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v0_dot_sequencing__pb2
from . import common_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v2_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>com/digitalasset/canton/protocol/v2/participant_transfer.proto\x12#com.digitalasset.canton.protocol.v2\x1a.com/digitalasset/canton/crypto/v0/crypto.proto\x1a\x34\x63om/digitalasset/canton/protocol/v0/sequencing.proto\x1a\x30\x63om/digitalasset/canton/protocol/v2/common.proto\"\xa1\x03\n\x0eTransferInView\x12;\n\x04salt\x18\x01 \x01(\x0b\x32\'.com.digitalasset.canton.crypto.v0.SaltR\x04salt\x12\x1c\n\tsubmitter\x18\x02 \x01(\tR\tsubmitter\x12U\n\x08\x63ontract\x18\x03 \x01(\x0b\x32\x39.com.digitalasset.canton.protocol.v2.SerializableContractR\x08\x63ontract\x12m\n\x19transfer_out_result_event\x18\x04 \x01(\x0b\x32\x32.com.digitalasset.canton.protocol.v0.SignedContentR\x16transferOutResultEvent\x12\x36\n\x17\x63reating_transaction_id\x18\x05 \x01(\x0cR\x15\x63reatingTransactionId\x12\x36\n\x17source_protocol_version\x18\x06 \x01(\x05R\x15sourceProtocolVersionBTZRgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.protocol.v2.participant_transfer_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZRgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v2'
  _globals['_TRANSFERINVIEW']._serialized_start=256
  _globals['_TRANSFERINVIEW']._serialized_end=673
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from __future__ import annotations

from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.user import User


T = TypeVar("T", bound="ListUsersResponse")


@_attrs_define
class ListUsersResponse:
    """
    Attributes:
        next_page_token (str): Pagination token to retrieve the next page.
            Empty, if there are no further results.
        users (list[User] | Unset): A subset of users of the participant node that fit into this page.
    """

    next_page_token: str
    users: list[User] | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        next_page_token = self.next_page_token

        users: list[dict[str, Any]] | Unset = UNSET
        if not isinstance(self.users, Unset):
            users = []
            for users_item_data in self.users:
                users_item = users_item_data.to_dict()
                users.append(users_item)

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "nextPageToken": next_page_token,
            }
        )
        if users is not UNSET:
            field_dict["users"] = users

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.user import User

        d = dict(src_dict)
        next_page_token = d.pop("nextPageToken")

        _users = d.pop("users", UNSET)
        users: list[User] | Unset = UNSET
        if _users is not UNSET:
            users = []
            for users_item_data in _users:
                users_item = User.from_dict(users_item_data)

                users.append(users_item)

        list_users_response = cls(
            next_page_token=next_page_token,
            users=users,
        )

        list_users_response.additional_properties = d
        return list_users_response

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from .. import value_pb2 as _value_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GlobalKey(_message.Message):
    __slots__ = ("template_id", "package_name", "key", "hash")
    TEMPLATE_ID_FIELD_NUMBER: _ClassVar[int]
    PACKAGE_NAME_FIELD_NUMBER: _ClassVar[int]
    KEY_FIELD_NUMBER: _ClassVar[int]
    HASH_FIELD_NUMBER: _ClassVar[int]
    template_id: _value_pb2.Identifier
    package_name: str
    key: _value_pb2.Value
    hash: bytes
    def __init__(self, template_id: _Optional[_Union[_value_pb2.Identifier, _Mapping]] = ..., package_name: _Optional[str] = ..., key: _Optional[_Union[_value_pb2.Value, _Mapping]] = ..., hash: _Optional[bytes] = ...) -> None: ...



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class SetPartyDisplayNameRequest(_message.Message):
    __slots__ = ("party_id", "display_name")
    PARTY_ID_FIELD_NUMBER: _ClassVar[int]
    DISPLAY_NAME_FIELD_NUMBER: _ClassVar[int]
    party_id: str
    display_name: str
    def __init__(self, party_id: _Optional[str] = ..., display_name: _Optional[str] = ...) -> None: ...

class SetPartyDisplayNameResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/admin/sequencer/v30/sequencer_connection.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/digitalasset/canton/admin/sequencer/v30/sequencer_connection.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFcom/digitalasset/canton/admin/sequencer/v30/sequencer_connection.proto\x12+com.digitalasset.canton.admin.sequencer.v30\x1a\x1egoogle/protobuf/duration.proto\"\x82\x03\n\x13SequencerConnection\x12[\n\x04grpc\x18\x02 \x01(\x0b\x32\x45.com.digitalasset.canton.admin.sequencer.v30.SequencerConnection.GrpcH\x00R\x04grpc\x12\x14\n\x05\x61lias\x18\x03 \x01(\tR\x05\x61lias\x12&\n\x0csequencer_id\x18\x04 \x01(\tH\x01R\x0bsequencerId\x88\x01\x01\x1a\xb6\x01\n\x04Grpc\x12 \n\x0b\x63onnections\x18\x01 \x03(\tR\x0b\x63onnections\x12-\n\x12transport_security\x18\x02 \x01(\x08R\x11transportSecurity\x12?\n\x19\x63ustom_trust_certificates\x18\x03 \x01(\x0cH\x00R\x17\x63ustomTrustCertificates\x88\x01\x01\x42\x1c\n\x1a_custom_trust_certificatesB\x06\n\x04typeB\x0f\n\r_sequencer_id\"\xb3\x04\n\x14SequencerConnections\x12u\n\x15sequencer_connections\x18\x01 \x03(\x0b\x32@.com.digitalasset.canton.admin.sequencer.v30.SequencerConnectionR\x14sequencerConnections\x12:\n\x19sequencer_trust_threshold\x18\x02 \x01(\rR\x17sequencerTrustThreshold\x12\x95\x01\n submission_request_amplification\x18\x03 \x01(\x0b\x32K.com.digitalasset.canton.admin.sequencer.v30.SubmissionRequestAmplificationR\x1esubmissionRequestAmplification\x12:\n\x19sequencer_liveness_margin\x18\x04 \x01(\rR\x17sequencerLivenessMargin\x12\x93\x01\n sequencer_connection_pool_delays\x18\x05 \x01(\x0b\x32J.com.digitalasset.canton.admin.sequencer.v30.SequencerConnectionPoolDelaysR\x1dsequencerConnectionPoolDelays\"o\n\x1eSubmissionRequestAmplification\x12\x16\n\x06\x66\x61\x63tor\x18\x01 \x01(\rR\x06\x66\x61\x63tor\x12\x35\n\x08patience\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationR\x08patience\"\xd5\x02\n\x1dSequencerConnectionPoolDelays\x12\x45\n\x11min_restart_delay\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationR\x0fminRestartDelay\x12\x45\n\x11max_restart_delay\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationR\x0fmaxRestartDelay\x12W\n\x1asubscription_request_delay\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationR\x18subscriptionRequestDelay\x12M\n\x15warn_validation_delay\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationR\x13warnValidationDelay*\x89\x02\n\x1dSequencerConnectionValidation\x12/\n+SEQUENCER_CONNECTION_VALIDATION_UNSPECIFIED\x10\x00\x12,\n(SEQUENCER_CONNECTION_VALIDATION_DISABLED\x10\x01\x12*\n&SEQUENCER_CONNECTION_VALIDATION_ACTIVE\x10\x02\x12\'\n#SEQUENCER_CONNECTION_VALIDATION_ALL\x10\x03\x12\x34\n0SEQUENCER_CONNECTION_VALIDATION_THRESHOLD_ACTIVE\x10\x04\x42\\ZZgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/sequencer/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.admin.sequencer.v30.sequencer_connection_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZZgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/sequencer/v30'
  _globals['_SEQUENCERCONNECTIONVALIDATION']._serialized_start=1564
  _globals['_SEQUENCERCONNECTIONVALIDATION']._serialized_end=1829
  _globals['_SEQUENCERCONNECTION']._serialized_start=152
  _globals['_SEQUENCERCONNECTION']._serialized_end=538
  _globals['_SEQUENCERCONNECTION_GRPC']._serialized_start=331
  _globals['_SEQUENCERCONNECTION_GRPC']._serialized_end=513
  _globals['_SEQUENCERCONNECTIONS']._serialized_start=541
  _globals['_SEQUENCERCONNECTIONS']._serialized_end=1104
  _globals['_SUBMISSIONREQUESTAMPLIFICATION']._serialized_start=1106
  _globals['_SUBMISSIONREQUESTAMPLIFICATION']._serialized_end=1217
  _globals['_SEQUENCERCONNECTIONPOOLDELAYS']._serialized_start=1220
  _globals['_SEQUENCERCONNECTIONPOOLDELAYS']._serialized_end=1561
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from . import participant_inspection_service_pb2 as com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_participant__inspection__service__pb2

GRPC_GENERATED_VERSION = '1.76.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + ' but the generated code in com/digitalasset/canton/admin/participant/v30/participant_inspection_service_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class ParticipantInspectionServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.LookupOffsetByTime = channel.unary_unary(
                '/com.digitalasset.canton.admin.participant.v30.ParticipantInspectionService/LookupOffsetByTime',
                request_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_participant__inspection__service__pb2.LookupOffsetByTimeRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_participant__inspection__service__pb2.LookupOffsetByTimeResponse.FromString,
                _registered_method=True)
        self.OpenCommitment = channel.unary_stream(
                '/com.digitalasset.canton.admin.participant.v30.ParticipantInspectionService/OpenCommitment',
                request_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_participant__inspection__service__pb2.OpenCommitmentRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_participant__inspection__service__pb2.OpenCommitmentResponse.FromString,
                _registered_method=True)
        self.InspectCommitmentContracts = channel.unary_stream(
                '/com.digitalasset.canton.admin.participant.v30.ParticipantInspectionService/InspectCommitmentContracts',
                request_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_participant__inspection__service__pb2.InspectCommitmentContractsRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_participant__inspection__service__pb2.InspectCommitmentContractsResponse.FromString,
                _registered_method=True)
        self.LookupSentAcsCommitments = channel.unary_unary(
                '/com.digitalasset.canton.admin.participant.v30.ParticipantInspectionService/LookupSentAcsCommitments',
                request_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_participant__inspection__service__pb2.LookupSentAcsCommitmentsRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_participant__inspection__service__pb2.LookupSentAcsCommitmentsResponse.FromString,
                _registered_method=True)
        self.LookupReceivedAcsCommitments = channel.unary_unary(
                '/com.digitalasset.canton.admin.participant.v30.ParticipantInspectionService/LookupReceivedAcsCommitments',
                request_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_participant__inspection__service__pb2.LookupReceivedAcsCommitmentsRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_participant__inspection__service__pb2.LookupReceivedAcsCommitmentsResponse.FromString,
                _registered_method=True)
        self.SetConfigForSlowCounterParticipants = channel.unary_unary(
                '/com.digitalasset.canton.admin.participant.v30.ParticipantInspectionService/SetConfigForSlowCounterParticipants',
                request_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_participant__inspection__service__pb2.SetConfigForSlowCounterParticipantsRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_participant__inspection__service__pb2.SetConfigForSlowCounterParticipantsResponse.FromString,
                _registered_method=True)
        self.GetConfigForSlowCounterParticipants = channel.unary_unary(
                '/com.digitalasset.canton.admin.participant.v30.ParticipantInspectionService/GetConfigForSlowCounterParticipants',
                request_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_participant__inspection__service__pb2.GetConfigForSlowCounterParticipantsRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_participant__inspection__service__pb2.GetConfigForSlowCounterParticipantsResponse.FromString,
                _registered_method=True)
        self.GetIntervalsBehindForCounterParticipants = channel.unary_unary(
                '/com.digitalasset.canton.admin.participant.v30.ParticipantInspectionService/GetIntervalsBehindForCounterParticipants',
                request_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_participant__inspection__service__pb2.GetIntervalsBehindForCounterParticipantsRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_participant__inspection__service__pb2.GetIntervalsBehindForCounterParticipantsResponse.FromString,
                _registered_method=True)
        self.CountInFlight = channel.unary_unary(
                '/com.digitalasset.canton.admin.participant.v30.ParticipantInspectionService/CountInFlight',
                request_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_participant__inspection__service__pb2.CountInFlightRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_participant__inspection__service__pb2.CountInFlightResponse.FromString,
                _registered_method=True)


class ParticipantInspectionServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def LookupOffsetByTime(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OpenCommitment(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InspectCommitmentContracts(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LookupSentAcsCommitments(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LookupReceivedAcsCommitments(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetConfigForSlowCounterParticipants(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetConfigForSlowCounterParticipants(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetIntervalsBehindForCounterParticipants(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CountInFlight(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ParticipantInspectionServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'LookupOffsetByTime': grpc.unary_unary_rpc_method_handler(
                    servicer.LookupOffsetByTime,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_participant__inspection__service__pb2.LookupOffsetByTimeRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_participant__inspection__service__pb2.LookupOffsetByTimeResponse.SerializeToString,
            ),
            'OpenCommitment': grpc.unary_stream_rpc_method_handler(
                    servicer.OpenCommitment,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_participant__inspection__service__pb2.OpenCommitmentRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_participant__inspection__service__pb2.OpenCommitmentResponse.SerializeToString,
            ),
            'InspectCommitmentContracts': grpc.unary_stream_rpc_method_handler(
                    servicer.InspectCommitmentContracts,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_participant__inspection__service__pb2.InspectCommitmentContractsRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_participant__inspection__service__pb2.InspectCommitmentContractsResponse.SerializeToString,
            ),
            'LookupSentAcsCommitments': grpc.unary_unary_rpc_method_handler(
                    servicer.LookupSentAcsCommitments,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_participant__inspection__service__pb2.LookupSentAcsCommitmentsRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_participant__inspection__service__pb2.LookupSentAcsCommitmentsResponse.SerializeToString,
            ),
            'LookupReceivedAcsCommitments': grpc.unary_unary_rpc_method_handler(
                    servicer.LookupReceivedAcsCommitments,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_participant__inspection__service__pb2.LookupReceivedAcsCommitmentsRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_participant__inspection__service__pb2.LookupReceivedAcsCommitmentsResponse.SerializeToString,
            ),
            'SetConfigForSlowCounterParticipants': grpc.unary_unary_rpc_method_handler(
                    servicer.SetConfigForSlowCounterParticipants,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_participant__inspection__service__pb2.SetConfigForSlowCounterParticipantsRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_participant__inspection__service__pb2.SetConfigForSlowCounterParticipantsResponse.SerializeToString,
            ),
            'GetConfigForSlowCounterParticipants': grpc.unary_unary_rpc_method_handler(
                    servicer.GetConfigForSlowCounterParticipants,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_participant__inspection__service__pb2.GetConfigForSlowCounterParticipantsRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_participant__inspection__service__pb2.GetConfigForSlowCounterParticipantsResponse.SerializeToString,
            ),
            'GetIntervalsBehindForCounterParticipants': grpc.unary_unary_rpc_method_handler(
                    servicer.GetIntervalsBehindForCounterParticipants,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_participant__inspection__service__pb2.GetIntervalsBehindForCounterParticipantsRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_participant__inspection__service__pb2.GetIntervalsBehindForCounterParticipantsResponse.SerializeToString,
            ),
            'CountInFlight': grpc.unary_unary_rpc_method_handler(
                    servicer.CountInFlight,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_participant__inspection__service__pb2.CountInFlightRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_participant__inspection__service__pb2.CountInFlightResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'com.digitalasset.canton.admin.participant.v30.ParticipantInspectionService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('com.digitalasset.canton.admin.participant.v30.ParticipantInspectionService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class ParticipantInspectionService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def LookupOffsetByTime(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.admin.participant.v30.ParticipantInspectionService/LookupOffsetByTime',
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_participant__inspection__service__pb2.LookupOffsetByTimeRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_participant__inspection__service__pb2.LookupOffsetByTimeResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def OpenCommitment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/com.digitalasset.canton.admin.participant.v30.ParticipantInspectionService/OpenCommitment',
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_participant__inspection__service__pb2.OpenCommitmentRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_participant__inspection__service__pb2.OpenCommitmentResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def InspectCommitmentContracts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/com.digitalasset.canton.admin.participant.v30.ParticipantInspectionService/InspectCommitmentContracts',
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_participant__inspection__service__pb2.InspectCommitmentContractsRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_participant__inspection__service__pb2.InspectCommitmentContractsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def LookupSentAcsCommitments(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.admin.participant.v30.ParticipantInspectionService/LookupSentAcsCommitments',
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_participant__inspection__service__pb2.LookupSentAcsCommitmentsRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_participant__inspection__service__pb2.LookupSentAcsCommitmentsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def LookupReceivedAcsCommitments(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.admin.participant.v30.ParticipantInspectionService/LookupReceivedAcsCommitments',
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_participant__inspection__service__pb2.LookupReceivedAcsCommitmentsRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_participant__inspection__service__pb2.LookupReceivedAcsCommitmentsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SetConfigForSlowCounterParticipants(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.admin.participant.v30.ParticipantInspectionService/SetConfigForSlowCounterParticipants',
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_participant__inspection__service__pb2.SetConfigForSlowCounterParticipantsRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_participant__inspection__service__pb2.SetConfigForSlowCounterParticipantsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetConfigForSlowCounterParticipants(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.admin.participant.v30.ParticipantInspectionService/GetConfigForSlowCounterParticipants',
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_participant__inspection__service__pb2.GetConfigForSlowCounterParticipantsRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_participant__inspection__service__pb2.GetConfigForSlowCounterParticipantsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetIntervalsBehindForCounterParticipants(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.admin.participant.v30.ParticipantInspectionService/GetIntervalsBehindForCounterParticipants',
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_participant__inspection__service__pb2.GetIntervalsBehindForCounterParticipantsRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_participant__inspection__service__pb2.GetIntervalsBehindForCounterParticipantsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CountInFlight(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.admin.participant.v30.ParticipantInspectionService/CountInFlight',
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_participant__inspection__service__pb2.CountInFlightRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_participant__inspection__service__pb2.CountInFlightResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="PrefetchContractKey")


@_attrs_define
class PrefetchContractKey:
    """Preload contracts

    Attributes:
        contract_key (Any): The key of the contract the client wants to prefetch.
            Required
        template_id (str | Unset): The template of contract the client wants to prefetch.
            Both package-name and package-id reference identifier formats for the template-id are supported.
            Note: The package-id reference identifier format is deprecated. We plan to end support for this format in
            version 3.4.

            Required
    """

    contract_key: Any
    template_id: str | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        contract_key = self.contract_key

        template_id = self.template_id

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "contractKey": contract_key,
            }
        )
        if template_id is not UNSET:
            field_dict["templateId"] = template_id

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        contract_key = d.pop("contractKey")

        template_id = d.pop("templateId", UNSET)

        prefetch_contract_key = cls(
            contract_key=contract_key,
            template_id=template_id,
        )

        prefetch_contract_key.additional_properties = d
        return prefetch_contract_key

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0

from __future__ import annotations

from .._gen_api import AuthenticatedClient, Client
from .._gen_api.openapi.api.default import (
    delete_v2_idps_idp_id,
    delete_v2_users_user_id,
    get_v2_authenticated_user,
    get_v2_idps,
    get_v2_idps_idp_id,
    get_v2_interactive_submission_preferred_package_version,
    get_v2_package_vetting,
    get_v2_packages,
    get_v2_packages_package_id,
    get_v2_packages_package_id_status,
    get_v2_parties,
    get_v2_parties_participant_id,
    get_v2_parties_party,
    get_v2_state_connected_synchronizers,
    get_v2_state_latest_pruned_offsets,
    get_v2_state_ledger_end,
    get_v2_updates_transaction_tree_by_id_update_id,
    get_v2_updates_transaction_tree_by_offset_offset,
    get_v2_users,
    get_v2_users_user_id,
    get_v2_users_user_id_rights,
    get_v2_version,
    patch_v2_idps_idp_id,
    patch_v2_parties_party,
    patch_v2_users_user_id,
    patch_v2_users_user_id_identity_provider_id,
    post_v2_commands_async_submit,
    post_v2_commands_completions,
    post_v2_commands_submit_and_wait,
    post_v2_commands_submit_and_wait_for_transaction_tree,
    post_v2_idps,
    post_v2_interactive_submission_preferred_packages,
    post_v2_packages,
    post_v2_parties,
    post_v2_parties_external_allocate,
    post_v2_parties_external_generate_topology,
)
from .._gen_api.openapi.models import (
    AllocateExternalPartyRequest,
    AllocateExternalPartyResponse,
    AllocatePartyRequest,
    AllocatePartyResponse,
    CompletionStreamRequest,
    CreateIdentityProviderConfigRequest,
    CreateIdentityProviderConfigResponse,
    DeleteIdentityProviderConfigResponse,
    GenerateExternalPartyTopologyRequest,
    GetIdentityProviderConfigResponse,
    GetLedgerApiVersionResponse,
    GetPreferredPackagesRequest,
    GetPreferredPackagesResponse,
    GetPreferredPackageVersionResponse,
    GetUserResponse,
    JsCommands,
    ListIdentityProviderConfigsResponse,
    ListKnownPartiesResponse,
    ListPackagesResponse,
    ListUsersResponse,
    ListVettedPackagesRequest,
    ListVettedPackagesResponse,
    PartyDetails,
    UpdateIdentityProviderConfigRequest,
    UpdateIdentityProviderConfigResponse,
    UpdatePartyDetailsRequest,
    UpdateUserIdentityProviderIdRequest,
    UpdateUserRequest,
    User,
)
from .._gen_api.openapi.types import File

__all__ = [
    "AuthenticatedClient",
    "Client",
    "File",
    "delete_v2_idps_idp_id",
    "delete_v2_users_user_id",
    "get_v2_authenticated_user",
    "get_v2_idps",
    "get_v2_idps_idp_id",
    "get_v2_interactive_submission_preferred_package_version",
    "get_v2_package_vetting",
    "get_v2_packages",
    "get_v2_packages_package_id",
    "get_v2_packages_package_id_status",
    "get_v2_parties",
    "get_v2_parties_participant_id",
    "get_v2_parties_party",
    "get_v2_state_connected_synchronizers",
    "get_v2_state_latest_pruned_offsets",
    "get_v2_state_ledger_end",
    "get_v2_updates_transaction_tree_by_id_update_id",
    "get_v2_updates_transaction_tree_by_offset_offset",
    "get_v2_users",
    "get_v2_users_user_id",
    "get_v2_users_user_id_rights",
    "get_v2_version",
    "patch_v2_idps_idp_id",
    "patch_v2_parties_party",
    "patch_v2_users_user_id",
    "patch_v2_users_user_id_identity_provider_id",
    "post_v2_commands_async_submit",
    "post_v2_commands_completions",
    "post_v2_commands_submit_and_wait",
    "post_v2_commands_submit_and_wait_for_transaction_tree",
    "post_v2_idps",
    "post_v2_interactive_submission_preferred_packages",
    "post_v2_packages",
    "post_v2_parties",
    "post_v2_parties_external_allocate",
    "post_v2_parties_external_generate_topology",
    "AllocateExternalPartyRequest",
    "AllocateExternalPartyResponse",
    "AllocatePartyRequest",
    "AllocatePartyResponse",
    "CompletionStreamRequest",
    "CreateIdentityProviderConfigRequest",
    "CreateIdentityProviderConfigResponse",
    "DeleteIdentityProviderConfigResponse",
    "GenerateExternalPartyTopologyRequest",
    "GetIdentityProviderConfigResponse",
    "GetLedgerApiVersionResponse",
    "GetPreferredPackageVersionResponse",
    "GetPreferredPackagesRequest",
    "GetPreferredPackagesResponse",
    "GetUserResponse",
    "JsCommands",
    "ListIdentityProviderConfigsResponse",
    "ListKnownPartiesResponse",
    "ListPackagesResponse",
    "ListUsersResponse",
    "ListVettedPackagesRequest",
    "ListVettedPackagesResponse",
    "PartyDetails",
    "UpdateIdentityProviderConfigRequest",
    "UpdateIdentityProviderConfigResponse",
    "UpdatePartyDetailsRequest",
    "UpdateUserIdentityProviderIdRequest",
    "UpdateUserRequest",
    "User",
]



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0

from __future__ import annotations

from datetime import datetime
from typing import AbstractSet, Iterable, Iterator, Optional

from ...damlast.protocols import SymbolLookup
from ...prim import ContractData, ContractId, Party

__all__ = ["Formatter", "RowBuilder", "TableBuilder"]


class Formatter:
    """
    A formatter is a particular way of representing a list of rows that represent contracts visible
    by a set of parties.
    """

    def render(
        self, lookup: SymbolLookup, parties: AbstractSet[Party], entries: Iterable[RowBuilder]
    ) -> Iterator[str]:
        """
        Render the set of entries.

        :param lookup: The store that contains type information.
        :param parties: Set of parties to render.
        :param entries: A list of entries to render.
        :return: An asynchronous generator over string lines that make up the rendering.
        """
        raise NotImplementedError("render needs an implementation")


class TableBuilder:
    """
    State built up during a ledger run.
    """

    def __init__(self) -> None:
        self.entries = dict[ContractId, RowBuilder]()

    def add(
        self,
        party: Party,
        cid: ContractId,
        cdata: ContractData,
        time: Optional[datetime] = None,
    ) -> None:
        entry = self.entries.get(cid)
        if entry is not None:
            entry.extend(party, cdata)
        else:
            self.entries[cid] = RowBuilder(party, cid, cdata, time)

    def excluding_inactive(self) -> Iterator[RowBuilder]:
        return filter(lambda e: not e.is_archived(), self)

    def filtered_by(self, predicate) -> Iterator[RowBuilder]:
        return filter(predicate, self)

    def __iter__(self) -> Iterator[RowBuilder]:
        return iter(self.entries.values())

    def __repr__(self) -> str:
        return "<LedgerCapture(entry_count={!r})>".format(len(self.entries))


class RowBuilder:
    """
    Represents a single "row" in the final output. This is a consolidation over the view that
    various parties see for a particular :class:`ContractId`.
    """

    def __init__(
        self, party: Party, cid: ContractId, cdata: ContractData, time: Optional[datetime]
    ):
        self.parties = {party: True}  # type: dict[Party, bool]
        self.cid = cid
        self.cdata = cdata
        self.time = time
        self.errors = list[Exception]()

    def extend(self, party: Party, cdata: Optional[ContractData]) -> None:
        self.parties[party] = cdata is not None

    def is_archived(self) -> bool:
        return all(not active for active in self.parties.values())

    def contract_state(self, party: Party) -> Optional[str]:
        p = self.parties.get(party)
        if p is not None:
            return "CREATED" if p else "ARCHIVED"
        else:
            return None

    def __repr__(self) -> str:
        return f"LedgerEntry(parties={self.parties}, cid={self.cid}, cdata={self.cdata})"



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0

from __future__ import annotations

from urllib.parse import urlparse

from grpc import ssl_channel_credentials
from grpc.aio import Channel, insecure_channel, secure_channel

from ..config import Config

__all__ = ["create_channel"]


def create_channel(config: Config) -> Channel:
    """
    Create a :class:`Channel` for the specified configuration.

    Note that the returned channel never carries authorization; the caller is expected to supply
    auth tokens on every request.
    """
    u = urlparse(config.url.url)

    options = [
        ("grpc.max_send_message_length", -1),
        ("grpc.max_receive_message_length", -1),
    ]
    if not config.url.use_http_proxy:
        options.append(("grpc.enable_http_proxy", 0))

    if (u.scheme in ("https", "grpcs")) or config.ssl:
        if config.ssl.ca is None and config.ssl.cert is not None:
            credentials = ssl_channel_credentials(root_certificates=config.ssl.cert)
        else:
            credentials = ssl_channel_credentials(
                root_certificates=config.ssl.ca,
                private_key=config.ssl.cert_key,
                certificate_chain=config.ssl.cert,
            )

        return secure_channel(u.netloc, credentials, tuple(options))
    else:
        return insecure_channel(u.netloc, options)



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/admin/participant/v30/resource_management_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/digitalasset/canton/admin/participant/v30/resource_management_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nOcom/digitalasset/canton/admin/participant/v30/resource_management_service.proto\x12-com.digitalasset.canton.admin.participant.v30\"x\n\x18SetResourceLimitsRequest\x12\\\n\nnew_limits\x18\x01 \x01(\x0b\x32=.com.digitalasset.canton.admin.participant.v30.ResourceLimitsR\tnewLimits\"\x1b\n\x19SetResourceLimitsResponse\"\x1a\n\x18GetResourceLimitsRequest\"\x81\x01\n\x19GetResourceLimitsResponse\x12\x64\n\x0e\x63urrent_limits\x18\x01 \x01(\x0b\x32=.com.digitalasset.canton.admin.participant.v30.ResourceLimitsR\rcurrentLimits\"\x8f\x02\n\x0eResourceLimits\x12L\n max_inflight_validation_requests\x18\x01 \x01(\rH\x00R\x1dmaxInflightValidationRequests\x88\x01\x01\x12\x33\n\x13max_submission_rate\x18\x02 \x01(\rH\x01R\x11maxSubmissionRate\x88\x01\x01\x12=\n\x1bmax_submission_burst_factor\x18\x03 \x01(\x01R\x18maxSubmissionBurstFactorB#\n!_max_inflight_validation_requestsB\x16\n\x14_max_submission_rate2\xed\x02\n\x19ResourceManagementService\x12\xa6\x01\n\x11SetResourceLimits\x12G.com.digitalasset.canton.admin.participant.v30.SetResourceLimitsRequest\x1aH.com.digitalasset.canton.admin.participant.v30.SetResourceLimitsResponse\x12\xa6\x01\n\x11GetResourceLimits\x12G.com.digitalasset.canton.admin.participant.v30.GetResourceLimitsRequest\x1aH.com.digitalasset.canton.admin.participant.v30.GetResourceLimitsResponseB^Z\\github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/participant/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.admin.participant.v30.resource_management_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\\github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/participant/v30'
  _globals['_SETRESOURCELIMITSREQUEST']._serialized_start=130
  _globals['_SETRESOURCELIMITSREQUEST']._serialized_end=250
  _globals['_SETRESOURCELIMITSRESPONSE']._serialized_start=252
  _globals['_SETRESOURCELIMITSRESPONSE']._serialized_end=279
  _globals['_GETRESOURCELIMITSREQUEST']._serialized_start=281
  _globals['_GETRESOURCELIMITSREQUEST']._serialized_end=307
  _globals['_GETRESOURCELIMITSRESPONSE']._serialized_start=310
  _globals['_GETRESOURCELIMITSRESPONSE']._serialized_end=439
  _globals['_RESOURCELIMITS']._serialized_start=442
  _globals['_RESOURCELIMITS']._serialized_end=713
  _globals['_RESOURCEMANAGEMENTSERVICE']._serialized_start=716
  _globals['_RESOURCEMANAGEMENTSERVICE']._serialized_end=1081
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class BftSequencerSnapshotAdditionalInfo(_message.Message):
    __slots__ = ("sequencers_active_at",)
    class SequencersActiveAtEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: BftSequencerSnapshotAdditionalInfo.SequencerActiveAt
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[BftSequencerSnapshotAdditionalInfo.SequencerActiveAt, _Mapping]] = ...) -> None: ...
    class SequencerActiveAt(_message.Message):
        __slots__ = ("timestamp", "start_epoch_number", "first_block_number_in_start_epoch", "start_epoch_topology_query_timestamp", "start_epoch_could_alter_ordering_topology", "previous_bft_time", "previous_epoch_topology_query_timestamp", "leader_selection_policy_state")
        TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
        START_EPOCH_NUMBER_FIELD_NUMBER: _ClassVar[int]
        FIRST_BLOCK_NUMBER_IN_START_EPOCH_FIELD_NUMBER: _ClassVar[int]
        START_EPOCH_TOPOLOGY_QUERY_TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
        START_EPOCH_COULD_ALTER_ORDERING_TOPOLOGY_FIELD_NUMBER: _ClassVar[int]
        PREVIOUS_BFT_TIME_FIELD_NUMBER: _ClassVar[int]
        PREVIOUS_EPOCH_TOPOLOGY_QUERY_TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
        LEADER_SELECTION_POLICY_STATE_FIELD_NUMBER: _ClassVar[int]
        timestamp: int
        start_epoch_number: int
        first_block_number_in_start_epoch: int
        start_epoch_topology_query_timestamp: int
        start_epoch_could_alter_ordering_topology: bool
        previous_bft_time: int
        previous_epoch_topology_query_timestamp: int
        leader_selection_policy_state: bytes
        def __init__(self, timestamp: _Optional[int] = ..., start_epoch_number: _Optional[int] = ..., first_block_number_in_start_epoch: _Optional[int] = ..., start_epoch_topology_query_timestamp: _Optional[int] = ..., start_epoch_could_alter_ordering_topology: bool = ..., previous_bft_time: _Optional[int] = ..., previous_epoch_topology_query_timestamp: _Optional[int] = ..., leader_selection_policy_state: _Optional[bytes] = ...) -> None: ...
    SEQUENCERS_ACTIVE_AT_FIELD_NUMBER: _ClassVar[int]
    sequencers_active_at: _containers.MessageMap[str, BftSequencerSnapshotAdditionalInfo.SequencerActiveAt]
    def __init__(self, sequencers_active_at: _Optional[_Mapping[str, BftSequencerSnapshotAdditionalInfo.SequencerActiveAt]] = ...) -> None: ...

class BlacklistLeaderSelectionPolicyState(_message.Message):
    __slots__ = ("epoch_number", "start_block_number", "blacklist")
    class BlacklistEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: BlacklistLeaderSelectionPolicyState.BlacklistStatus
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[BlacklistLeaderSelectionPolicyState.BlacklistStatus, _Mapping]] = ...) -> None: ...
    class BlacklistStatus(_message.Message):
        __slots__ = ("on_trial", "blacklisted")
        class OnTrial(_message.Message):
            __slots__ = ("failed_attempts_before_trial",)
            FAILED_ATTEMPTS_BEFORE_TRIAL_FIELD_NUMBER: _ClassVar[int]
            failed_attempts_before_trial: int
            def __init__(self, failed_attempts_before_trial: _Optional[int] = ...) -> None: ...
        class Blacklisted(_message.Message):
            __slots__ = ("failed_attempts_before", "epochs_left_until_new_trial")
            FAILED_ATTEMPTS_BEFORE_FIELD_NUMBER: _ClassVar[int]
            EPOCHS_LEFT_UNTIL_NEW_TRIAL_FIELD_NUMBER: _ClassVar[int]
            failed_attempts_before: int
            epochs_left_until_new_trial: int
            def __init__(self, failed_attempts_before: _Optional[int] = ..., epochs_left_until_new_trial: _Optional[int] = ...) -> None: ...
        ON_TRIAL_FIELD_NUMBER: _ClassVar[int]
        BLACKLISTED_FIELD_NUMBER: _ClassVar[int]
        on_trial: BlacklistLeaderSelectionPolicyState.BlacklistStatus.OnTrial
        blacklisted: BlacklistLeaderSelectionPolicyState.BlacklistStatus.Blacklisted
        def __init__(self, on_trial: _Optional[_Union[BlacklistLeaderSelectionPolicyState.BlacklistStatus.OnTrial, _Mapping]] = ..., blacklisted: _Optional[_Union[BlacklistLeaderSelectionPolicyState.BlacklistStatus.Blacklisted, _Mapping]] = ...) -> None: ...
    EPOCH_NUMBER_FIELD_NUMBER: _ClassVar[int]
    START_BLOCK_NUMBER_FIELD_NUMBER: _ClassVar[int]
    BLACKLIST_FIELD_NUMBER: _ClassVar[int]
    epoch_number: int
    start_block_number: int
    blacklist: _containers.MessageMap[str, BlacklistLeaderSelectionPolicyState.BlacklistStatus]
    def __init__(self, epoch_number: _Optional[int] = ..., start_block_number: _Optional[int] = ..., blacklist: _Optional[_Mapping[str, BlacklistLeaderSelectionPolicyState.BlacklistStatus]] = ...) -> None: ...



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

from .bft_ordering_service_pb2 import AvailabilityAck, AvailabilityMessage, Batch, BatchRequest, BatchResponse, BftOrderingMessage, BftOrderingMessageBody, BlockInProgress, BlockMetadata, BlockStatus, BlockTransferRequest, BlockTransferResponse, CanonicalCommitSet, Commit, CommitCertificate, ConnectionOpened, ConsensusCertificate, ConsensusMessage, EpochStatus, NewView, OrderingBlock, OrderingRequest, PrePrepare, Prepare, PrepareCertificate, ProofOfAvailability, RetransmissionMessage, RetransmissionResponse, SegmentInProgress, SegmentInViewChange, SegmentStatus, SignedMessage, StateTransferMessage, StoreRequest, StoreResponse, ViewChange
from .bft_ordering_service_pb2_grpc import BftOrderingServiceStub
from .dynamic_sequencing_parameters_pb2 import DynamicSequencingParametersPayload

__all__ = [
    "AvailabilityAck",
    "AvailabilityMessage",
    "Batch",
    "BatchRequest",
    "BatchResponse",
    "BftOrderingMessage",
    "BftOrderingMessageBody",
    "BftOrderingServiceStub",
    "BlockInProgress",
    "BlockMetadata",
    "BlockStatus",
    "BlockTransferRequest",
    "BlockTransferResponse",
    "CanonicalCommitSet",
    "Commit",
    "CommitCertificate",
    "ConnectionOpened",
    "ConsensusCertificate",
    "ConsensusMessage",
    "DynamicSequencingParametersPayload",
    "EpochStatus",
    "NewView",
    "OrderingBlock",
    "OrderingRequest",
    "PrePrepare",
    "Prepare",
    "PrepareCertificate",
    "ProofOfAvailability",
    "RetransmissionMessage",
    "RetransmissionResponse",
    "SegmentInProgress",
    "SegmentInViewChange",
    "SegmentStatus",
    "SignedMessage",
    "StateTransferMessage",
    "StoreRequest",
    "StoreResponse",
    "ViewChange",
]



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.js_prepare_submission_response_hashing_scheme_version import (
    JsPrepareSubmissionResponseHashingSchemeVersion,
)
from ..types import UNSET, Unset

T = TypeVar("T", bound="JsPrepareSubmissionResponse")


@_attrs_define
class JsPrepareSubmissionResponse:
    """[docs-entry-end: HashingSchemeVersion]

    Attributes:
        prepared_transaction_hash (str): Hash of the transaction, this is what needs to be signed by the party to
            authorize the transaction.
            Only provided for convenience, clients MUST recompute the hash from the raw transaction if the preparing
            participant is not trusted.
            May be removed in future versions
        hashing_scheme_version (JsPrepareSubmissionResponseHashingSchemeVersion): The hashing scheme version used when
            building the hash
        prepared_transaction (str | Unset): The interpreted transaction, it represents the ledger changes necessary to
            execute the commands specified in the request.
            Clients MUST display the content of the transaction to the user for them to validate before signing the hash if
            the preparing participant is not trusted.
        hashing_details (str | Unset): Optional additional details on how the transaction was encoded and hashed. Only
            set if verbose_hashing = true in the request
            Note that there are no guarantees on the stability of the format or content of this field.
            Its content should NOT be parsed and should only be used for troubleshooting purposes.
    """

    prepared_transaction_hash: str
    hashing_scheme_version: JsPrepareSubmissionResponseHashingSchemeVersion
    prepared_transaction: str | Unset = UNSET
    hashing_details: str | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        prepared_transaction_hash = self.prepared_transaction_hash

        hashing_scheme_version = self.hashing_scheme_version.value

        prepared_transaction = self.prepared_transaction

        hashing_details = self.hashing_details

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "preparedTransactionHash": prepared_transaction_hash,
                "hashingSchemeVersion": hashing_scheme_version,
            }
        )
        if prepared_transaction is not UNSET:
            field_dict["preparedTransaction"] = prepared_transaction
        if hashing_details is not UNSET:
            field_dict["hashingDetails"] = hashing_details

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        prepared_transaction_hash = d.pop("preparedTransactionHash")

        hashing_scheme_version = JsPrepareSubmissionResponseHashingSchemeVersion(
            d.pop("hashingSchemeVersion")
        )

        prepared_transaction = d.pop("preparedTransaction", UNSET)

        hashing_details = d.pop("hashingDetails", UNSET)

        js_prepare_submission_response = cls(
            prepared_transaction_hash=prepared_transaction_hash,
            hashing_scheme_version=hashing_scheme_version,
            prepared_transaction=prepared_transaction,
            hashing_details=hashing_details,
        )

        js_prepare_submission_response.additional_properties = d
        return js_prepare_submission_response

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from __future__ import annotations

from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.experimental_command_inspection_service import (
        ExperimentalCommandInspectionService,
    )
    from ..models.experimental_static_time import ExperimentalStaticTime


T = TypeVar("T", bound="ExperimentalFeatures")


@_attrs_define
class ExperimentalFeatures:
    """See the feature message definitions for descriptions.

    Attributes:
        static_time (ExperimentalStaticTime | Unset): Ledger is in the static time mode and exposes a time service.
        command_inspection_service (ExperimentalCommandInspectionService | Unset): Whether the Ledger API supports
            command inspection service
    """

    static_time: ExperimentalStaticTime | Unset = UNSET
    command_inspection_service: ExperimentalCommandInspectionService | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        static_time: dict[str, Any] | Unset = UNSET
        if not isinstance(self.static_time, Unset):
            static_time = self.static_time.to_dict()

        command_inspection_service: dict[str, Any] | Unset = UNSET
        if not isinstance(self.command_inspection_service, Unset):
            command_inspection_service = self.command_inspection_service.to_dict()

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if static_time is not UNSET:
            field_dict["staticTime"] = static_time
        if command_inspection_service is not UNSET:
            field_dict["commandInspectionService"] = command_inspection_service

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.experimental_command_inspection_service import (
            ExperimentalCommandInspectionService,
        )
        from ..models.experimental_static_time import ExperimentalStaticTime

        d = dict(src_dict)
        _static_time = d.pop("staticTime", UNSET)
        static_time: ExperimentalStaticTime | Unset
        if isinstance(_static_time, Unset):
            static_time = UNSET
        else:
            static_time = ExperimentalStaticTime.from_dict(_static_time)

        _command_inspection_service = d.pop("commandInspectionService", UNSET)
        command_inspection_service: ExperimentalCommandInspectionService | Unset
        if isinstance(_command_inspection_service, Unset):
            command_inspection_service = UNSET
        else:
            command_inspection_service = ExperimentalCommandInspectionService.from_dict(
                _command_inspection_service
            )

        experimental_features = cls(
            static_time=static_time,
            command_inspection_service=command_inspection_service,
        )

        experimental_features.additional_properties = d
        return experimental_features

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
